summaryrefslogtreecommitdiff
path: root/lib/reconnect.h
diff options
context:
space:
mode:
authorBen Pfaff <blp@nicira.com>2012-08-08 13:32:57 -0700
committerBen Pfaff <blp@nicira.com>2012-09-07 10:48:43 -0700
commita6f639f8080fe18120bb205609c6e364f6de7e70 (patch)
tree0bc8d22143b241caba7610e1982f72221a6e4b6f /lib/reconnect.h
parente0f3585d4499db4ad0f22fd3c4749ba2e9814c33 (diff)
downloadopenvswitch-a6f639f8080fe18120bb205609c6e364f6de7e70.tar.gz
reconnect: Rename reconnect_received() to reconnect_activity().
Receiving data is not the only reasonable way to verify that a connection is up. For example, on a TCP connection, receiving an acknowledgment that the remote side has accepted data that we sent is also a reasonable means. Therefore, this commit generalizes the naming. Also, similarly for the Python implementation: Reconnect.received() becomes Reconnect.activity(). Signed-off-by: Ben Pfaff <blp@nicira.com>
Diffstat (limited to 'lib/reconnect.h')
-rw-r--r--lib/reconnect.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/reconnect.h b/lib/reconnect.h
index e935d0af0..4446713ce 100644
--- a/lib/reconnect.h
+++ b/lib/reconnect.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2009, 2010 Nicira, Inc.
+ * Copyright (c) 2009, 2010, 2012 Nicira, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -79,7 +79,7 @@ void reconnect_listen_error(struct reconnect *, long long int now, int error);
void reconnect_connected(struct reconnect *, long long int now);
void reconnect_connect_failed(struct reconnect *, long long int now,
int error);
-void reconnect_received(struct reconnect *, long long int now);
+void reconnect_activity(struct reconnect *, long long int now);
enum reconnect_action {
RECONNECT_CONNECT = 1,
@@ -93,7 +93,7 @@ int reconnect_timeout(struct reconnect *, long long int now);
struct reconnect_stats {
/* All times and durations in this structure are in milliseconds. */
long long int creation_time; /* Time reconnect_create() called. */
- long long int last_received; /* Last call to reconnect_received(). */
+ long long int last_activity; /* Last call to reconnect_activity(). */
long long int last_connected; /* Last call to reconnect_connected(). */
long long int last_disconnected; /* Last call to reconnect_disconnected(). */
int backoff; /* Current backoff duration. */